<?PHP
/**
 * Contains a class for controlling the list of available units.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Class containing available units for weights, lengths etc.
 */
final class MDUnitsSet extends MDValueSet {

    const UNITS_LENGTH = ['', 'm', 'dm', 'cm', 'mm'];
    const UNITS_WEIGHT = ['', 't', 'kg', 'g'];

    /**
     * Returns a translated list of length units.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string>
     */
    public static function getLengthUnitsTLed(MDTlLoader $tlLoader):array {
        return parent::getTlUnsortedList($tlLoader, self::UNITS_LENGTH, "units_length_set", "units_length_set");

    }

    /**
     * Returns a translated list of weight units.
     *
     * @param MDTlLoader $tlLoader Translation loader.
     *
     * @return array<string>
     */
    public static function getWeightUnitsTLed(MDTlLoader $tlLoader):array {
        return parent::getTlUnsortedList($tlLoader, self::UNITS_WEIGHT, "units_weight_set", "units_weight_set");

    }

}
